@@ -34,8 +34,11 @@ from __future__ import(division, absolute_import, print_function,
                        unicode_literals)
 
 import codecs
-import re
 import io
+from itertools import izip as zip
+import re
+
+
 import httplib2
 import lxml.html
 from lxml.html.clean import clean_html
@@ -52,7 +55,8 @@ def get_text_file(name):
         html_tree = lxml.html.fromstring(content)
         clean_html(html_tree)  # removes crud from html
         clean_html_string = lxml.html.tostring(html_tree, 
-                                               encoding=unicode, method='text')
+                                               encoding=unicode,
+                                               method='text')
         file = io.StringIO(clean_html_string)
     else:
         file = codecs.open(name, encoding='utf-8')
@@ -68,23 +72,23 @@ def get_named_text_files(*names):
     and/or urls (convenience function)
     '''
     return zip(names, get_text_files(*names))
-    
-def term_vec(file):
+
+def term_vec(file, stoplist = None):
     '''
     Returns a term vector for 'file', represented as a dictionary
     of the form {term: frequency}
-    
-    Takes ownership of file   
     '''
+    # default args:
+    if stoplist is None:
+        stoplist = set()
     
-    with file as f:
-        tf_dict = {}
-        for line in f:
-            for term in line.split():
-                if not term in tf_dict:
-                    tf_dict[term] = 0
+    tf_dict = {}
+    for line in file:
+        for term in line.split():
+            if term not in stoplist:
+                if term not in tf_dict: tf_dict[term] = 0
                 tf_dict[term] += 1
-        return tf_dict
+    return tf_dict
     
 def term_vec_from_string(s):
     '''
@@ -93,5 +97,6 @@ def term_vec_from_string(s):
 
     (Convenience function - wraps term_vec())
     '''
-    return term_vec(io.StringIO(s))
+    with io.StringIO(s) as string_buffer:
+        return term_vec(string_buffer)
     
\ No newline at end of file
