@@ -41,7 +41,7 @@ to sim_index.
     bash$ ./sim_server.py sim_index -p 9001
     Use Control-C to exit
 
-**Client**
+**jsonrpclib Client**
 
 >>> from pprint import pprint
 >>> import jsonrpclib
@@ -51,7 +51,12 @@ to sim_index.
 [[u'http://www.stanford.edu/', 0.10469570845856098],
  [u'http://www.ucla.edu', 0.04485065887313478],
  [u'http://www.berkeley.edu', 0.020464326883958977]]
->>> pprint(server.sim_index.query_by_string('university'))
+
+** pysimsearch Client **
+>>> from pysimsearch import sim_index
+>>> index = sim_index.RemoteSimIndex('http://localhost:9001/RPC2')
+>>> index.index_filenames('http://www.stanford.edu/', 'http://www.berkeley.edu', 'http://www.ucla.edu')
+>>> pprint(index.query_by_string('university'))
 [[u'http://www.stanford.edu/', 0.10469570845856098],
  [u'http://www.ucla.edu', 0.04485065887313478],
  [u'http://www.berkeley.edu', 0.020464326883958977]]
@@ -104,9 +109,13 @@ class SimIndexService(object):
                         'set_global_df_map',
                         'get_global_df_map',
                         'get_local_df_map',
-                        'get_name_to_docid_map'}
+                        'get_name_to_docid_map',
+                        'config',
+                        'set_config',
+                        'update_config'}
+    
     def __init__(self):
-        self._sim_index = sim_index.SimpleMemorySimIndex()
+        self._sim_index = sim_index.MemorySimIndex()
         self._sim_index.set_query_scorer(query_scorer.TFIDFQueryScorer())
     
     def _dispatch(self, method, params):
@@ -122,7 +131,10 @@ class SimIndexService(object):
             
         func = getattr(self._sim_index, method_name)
         try:
-            r = func(*params)
+            if type(params) is types.ListType:
+                r = func(*params)
+            else:
+                r = func(**params)
             # if we got back a generator, then let's materialize a list so it
             # can serialize properly
             if isinstance(r, types.GeneratorType):
@@ -136,11 +148,11 @@ class SimIndexService(object):
 class RequestHandler(SimpleRPCRequestHandler):
     rpc_paths = ('/RPC2',)
 
-def start_sim_index_server(port):
+def start_sim_index_server(port, logRequests = True):
     server = SimpleRPCServer(('localhost', port),
-                                 logRequests = True,
-                                 requestHandler = RequestHandler)
-
+                             logRequests = logRequests,
+                             requestHandler = RequestHandler)
+    
     server.register_instance(SimIndexService())
 
     try:
